<div align="center">
  <a href="https://v2.nonebot.dev/store">
    <img src="https://raw.githubusercontent.com/A-kirami/nonebot-plugin-template/resources/nbp_logo.png" width="180" height="180" alt="logo">
  </a>
  <br>
  <p>
    <img src="https://raw.githubusercontent.com/A-kirami/nonebot-plugin-template/resources/NoneBotPlugin.svg" width="240" alt="logo">
  </p>
</div>

<div align="center">

# nonebot-plugin-sanyao

_✨ NoneBot 插件简单描述 ✨_


<a href="./LICENSE">
    <img src="https://img.shields.io/github/license/owner/nonebot-plugin-template.svg" alt="license">
</a>
<a href="https://pypi.python.org/pypi/nonebot-plugin-sanyao">
    <img src="https://img.shields.io/pypi/v/nonebot-plugin-sanyao.svg" alt="pypi">
</a>
<img src="https://img.shields.io/badge/python-3.8+-blue.svg" alt="python">

</div>

这是一个 三爻易数插件

## 📖 介绍

这里是一个 三爻易数插件，后续增加64卦

## 💿 安装

<details open>
<summary>使用 nb-cli 安装</summary>
在 nonebot2 项目的根目录下打开命令行, 输入以下指令即可安装

    nb plugin install nonebot-plugin-sanyao

</details>

<details>
<summary>使用包管理器安装</summary>
在 nonebot2 项目的插件目录下, 打开命令行, 根据你使用的包管理器, 输入相应的安装命令

<details>
<summary>pip</summary>

    pip install nonebot-plugin-sanyao
</details>
<details>
<summary>pdm</summary>

    pdm add nonebot-plugin-sanyao
</details>
<details>
<summary>poetry</summary>

    poetry add nonebot-plugin-sanyao
</details>
<details>
<summary>conda</summary>

    conda install nonebot-plugin-sanyao
</details>

打开 nonebot2 项目根目录下的 `pyproject.toml` 文件, 在 `[tool.nonebot]` 部分追加写入

    plugins = ["nonebot_plugin_template"]

</details>

## ⚙️ 配置

在 nonebot2 项目的`.env`文件中添加下表中的必填配置

| 配置项 | 必填 | 默认值 | 说明 |
|:---:|:--:|:---:|:--:|
|  无  | 否  |  无  | 无  |
|  无  | 否  |  无  | 无  |

## 🎉 使用
### 指令表
|  指令  | 权限 | 需要@ | 范围 |  说明  |
|:----:|:--:|:---:|:--:|:----:|
| 三爻排盘 | 群员 |  否  | 私聊 | 开始排盘 |
|  三爻  | 群员 |  否  | 群聊 | 开始排盘 |
### 效果图
如果有效果图的话
